Index: /utils/CI/sette/input_AGRIF.cfg
===================================================================
--- /utils/CI/sette/input_AGRIF.cfg	(revision 9662)
+++ /utils/CI/sette/input_AGRIF.cfg	(revision 9663)
@@ -1,2 +1,2 @@
 ORCA2_ICE_v4.0.tar ORCA2_ICE_v4.0
-AGRIF_NORDIC_v4.0.tar AGRIF_NORDIC_v4.0
+AGRIF_ICE_v4.0.tar AGRIF_ICE_v4.0
Index: /utils/CI/sette/input_ORCA2_ICE_AGRIF.cfg
===================================================================
--- /utils/CI/sette/input_ORCA2_ICE_AGRIF.cfg	(revision 9663)
+++ /utils/CI/sette/input_ORCA2_ICE_AGRIF.cfg	(revision 9663)
@@ -0,0 +1,1 @@
+ORCA2_ICE_v4.0.tar ORCA2_ICE_v4.0
Index: /utils/CI/sette/input_ORCA2_ICE_OBS.cfg
===================================================================
--- /utils/CI/sette/input_ORCA2_ICE_OBS.cfg	(revision 9663)
+++ /utils/CI/sette/input_ORCA2_ICE_OBS.cfg	(revision 9663)
@@ -0,0 +1,1 @@
+ORCA2_ICE_v4.0.tar ORCA2_ICE_v4.0
Index: /utils/CI/sette/input_ORCA2_ICE_PISCES.cfg
===================================================================
--- /utils/CI/sette/input_ORCA2_ICE_PISCES.cfg	(revision 9663)
+++ /utils/CI/sette/input_ORCA2_ICE_PISCES.cfg	(revision 9663)
@@ -0,0 +1,1 @@
+ORCA2_ICE_v4.0.tar  ORCA2_ICE_v4.0
Index: ils/CI/sette/input_ORCA2_SI3_AGRIF.cfg
===================================================================
--- /utils/CI/sette/input_ORCA2_SI3_AGRIF.cfg	(revision 9662)
+++ 	(revision )
@@ -1,1 +1,0 @@
-ORCA2_ICE_v4.0.tar ORCA2_ICE_v4.0
Index: ils/CI/sette/input_ORCA2_SI3_OBS.cfg
===================================================================
--- /utils/CI/sette/input_ORCA2_SI3_OBS.cfg	(revision 9662)
+++ 	(revision )
@@ -1,1 +1,0 @@
-ORCA2_ICE_v4.0.tar ORCA2_ICE_v4.0
Index: ils/CI/sette/input_ORCA2_SI3_PISCES.cfg
===================================================================
--- /utils/CI/sette/input_ORCA2_SI3_PISCES.cfg	(revision 9662)
+++ 	(revision )
@@ -1,1 +1,0 @@
-ORCA2_ICE_v4.0.tar  ORCA2_ICE_v4.0
Index: /utils/CI/sette/param.cfg
===================================================================
--- /utils/CI/sette/param.cfg	(revision 9662)
+++ /utils/CI/sette/param.cfg	(revision 9663)
@@ -1,4 +1,4 @@
 #- forcing files storing
-FORCING_DIR=$WORKDIR/NEMO/FORC
+FORCING_DIR=$WORKDIR/FORCING
 #- input files storing
 INPUT_DIR=${CONFIG_DIR}/${NEW_CONF}/EXP00
@@ -6,3 +6,3 @@
 #TMPDIR=${CONFIG_DIR}/${NEW_CONF}/EXP00
 #- VALIDATION files storing
-NEMO_VALIDATION_DIR=~/CNRS_merge_2017
+NEMO_VALIDATION_DIR=$WORKDIR/NEMO_VALIDATION
Index: /utils/CI/sette/prepare_job.sh
===================================================================
--- /utils/CI/sette/prepare_job.sh	(revision 9662)
+++ /utils/CI/sette/prepare_job.sh	(revision 9663)
@@ -69,5 +69,5 @@
 
 usage=" Usage : ./prepare_job.sh INPUT_FILE_CONFIG_NAME NUMBER_PROC TEST_NAME MPI_FLAG JOB_FILE NUM_XIO_SERVERS"
-usage=" example : ./prepare_job.sh input_ORCA2_LIM_PISCES.cfg 8 SHORT no/yes $JOB_FILE 0 2"
+usage=" example : ./prepare_job.sh input_ORCA2_ICE_PISCES.cfg 8 SHORT no/yes $JOB_FILE 0 2"
 
 
Index: /utils/CI/sette/sette_chk_result.sh
===================================================================
--- /utils/CI/sette/sette_chk_result.sh	(revision 9662)
+++ /utils/CI/sette/sette_chk_result.sh	(revision 9663)
@@ -488,5 +488,5 @@
 # Restartability test
 #
- for restart_test in WGYREPIS_ST WORCA2SI3PIS_ST WORCA2OFFPIS_ST WAMM12_ST WISOMIP_ST WORCA2AGR_ST
+ for restart_test in WGYREPIS_ST WORCA2ICEPIS_ST WORCA2OFFPIS_ST WAMM12_ST WISOMIP_ST WORCA2AGR_ST
  do
    resttest $NEMO_VALID $restart_test $pass
@@ -495,5 +495,5 @@
 # Reproducibility tests
 #
- for repro_test in WGYREPIS_ST WORCA2SI3PIS_ST WORCA2OFFPIS_ST WAMM12_ST WISOMIP_ST WORCA2_SI3_OBS_ST WORCA2AGR_ST
+ for repro_test in WGYREPIS_ST WORCA2ICEPIS_ST WORCA2OFFPIS_ST WAMM12_ST WISOMIP_ST WORCA2_ICE_OBS_ST WORCA2AGR_ST
  do
    reprotest $NEMO_VALID $repro_test $pass
@@ -515,5 +515,5 @@
    echo 'and'
    echo "$NEMO_VALID_REF at rev $NEMO_REV_REF"
-   for repro_test in WGYREPIS_ST WORCA2SI3PIS_ST WORCA2OFFPIS_ST WAMM12_ST WISOMIP_ST WORCA2_SI3_OBS_ST WORCA2AGR_ST
+   for repro_test in WGYREPIS_ST WORCA2ICEPIS_ST WORCA2OFFPIS_ST WAMM12_ST WISOMIP_ST WORCA2_ICE_OBS_ST WORCA2AGR_ST
    do
      runcmpres $NEMO_VALID $repro_test $NEMO_VALID_REF $NEMO_REV_REF $pass
Index: /utils/CI/sette/sette_rpt.SAS.sh
===================================================================
--- /utils/CI/sette/sette_rpt.SAS.sh	(revision 9662)
+++ /utils/CI/sette/sette_rpt.SAS.sh	(revision 9663)
@@ -301,5 +301,5 @@
 # Restartability test
 #
- for restart_test in WGYREPIS_LONG WORCA2SI3PIS_LONG WORCA2OFFPIS_LONG WAMM12_LONG WISOMIP_LONG WORCA2AGUL_LONG
+ for restart_test in WGYREPIS_LONG WORCA2ICEPIS_LONG WORCA2OFFPIS_LONG WAMM12_LONG WISOMIP_LONG WORCA2AGUL_LONG
  do
    resttest $NEMO_VALID $restart_test $pass
@@ -308,5 +308,5 @@
 # Reproducibility tests
 #
- for repro_test in WGYREPIS_32 WORCA2SI3PIS_32 WORCA2OFFPIS_32 WAMM12_32 WISOMIP_32 WORCA2_SI3_OBS WORCA2AGUL_1_2 WORCA2AGUL_16 WORCA2AGUL_2_2_NAG
+ for repro_test in WGYREPIS_32 WORCA2ICEPIS_32 WORCA2OFFPIS_32 WAMM12_32 WISOMIP_32 WORCA2_ICE_OBS WORCA2AGUL_1_2 WORCA2AGUL_16 WORCA2AGUL_2_2_NAG
  do
    reprotest $NEMO_VALID $repro_test $pass
Index: /utils/CI/sette/sette_rpt.sh
===================================================================
--- /utils/CI/sette/sette_rpt.sh	(revision 9662)
+++ /utils/CI/sette/sette_rpt.sh	(revision 9663)
@@ -35,7 +35,7 @@
     cd ${TOOLS_DIR}/REBUILD_NEMO
     #SF echo "REBUILD LONG restart SAS files, without standard output"
-    ./rebuild_nemo -t 4 ../../cfgs/ORCA2_SAS_SI3_ST/LONG/SAS_00000240_restart_ice  $NPROC > /dev/null 2>&1
+    ./rebuild_nemo -t 4 ../../cfgs/ORCA2_SAS_ICE_ST/LONG/SAS_00000240_restart_ice  $NPROC > /dev/null 2>&1
     #SF echo "REBUILD SHORT restart SAS files, without standard output"
-    ./rebuild_nemo -t 4 ../../cfgs/ORCA2_SAS_SI3_ST/SHORT/SAS_00000240_restart_ice $NPROC >&-
+    ./rebuild_nemo -t 4 ../../cfgs/ORCA2_SAS_ICE_ST/SHORT/SAS_00000240_restart_ice $NPROC >&-
     cd ${SAS_RESTART_DIR}/LONG
     #SF echo "COPY rebuild restart files"
@@ -386,5 +386,5 @@
   TOOLS_DIR=${MAIN_DIR}/tools
   NPROC=32
-  SAS_RESTART_DIR=${CONFIG_DIR0}/ORCA2_SAS_SI3_ST
+  SAS_RESTART_DIR=${CONFIG_DIR0}/ORCA2_SAS_ICE_ST
 #
 # Show current revision tag and branch name
@@ -416,5 +416,5 @@
 # Rebuild and restartability test for SAS
 # clem: not needed anymore
-# for restart_file in WORCA2_SAS_SI3_ST
+# for restart_file in WORCA2_SAS_ICE_ST
 # do
 #   restfile $NEMO_VALID $restart_file $pass
@@ -424,5 +424,5 @@
  echo ""
  echo "   !----restart----!   "
- for restart_test in WGYRE_PISCES_ST WORCA2_SI3_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_SI3_ST WAGRIF_NORDIC_ST WSPITZ12_ST WISOMIP_ST WOVERFLOW_ST WLOCK_EXCHANGE_ST WVORTEX_ST WWAD_ST WSAS_BIPER_ST 
+ for restart_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_ICE_ST WAGRIF_ICE_ST WSPITZ12_ST WISOMIP_ST WOVERFLOW_ST WLOCK_EXCHANGE_ST WVORTEX_ST WWAD_ST WSAS_BIPER_ST 
  do
    resttest $NEMO_VALID $restart_test $pass
@@ -432,5 +432,5 @@
  echo ""
  echo "   !----repro----!   "
- for repro_test in WGYRE_PISCES_ST WORCA2_SI3_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_SI3_ST WORCA2_SI3_OBS_ST WAGRIF_NORDIC_ST WSPITZ12_ST WISOMIP_ST
+ for repro_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_ICE_ST WORCA2_ICE_OBS_ST WAGRIF_ICE_ST WSPITZ12_ST WISOMIP_ST
  do
    reprotest $NEMO_VALID $repro_test $pass
@@ -441,6 +441,6 @@
  echo ""
  echo "   !----agrif check----!   "
- dir1=WAGRIF_NORDIC_NOAGRIF_ST
- dir2=WAGRIF_NORDIC_ST
+ dir1=WAGRIF_ICE_NOAGRIF_ST
+ dir2=WAGRIF_ICE_ST
  identictest $NEMO_VALID $dir1 $dir2 $pass 
 

Index: /utils/CI/sette/sette.sh
===================================================================
--- /utils/CI/sette/sette.sh	(revision 9662)
+++ /utils/CI/sette/sette.sh	(revision 9663)
@@ -133,10 +133,10 @@
 # Description of configuration tested:
 # GYRE_PISCES       :  1 
-# ORCA2_SI3_PISCES  :  2 
+# ORCA2_ICE_PISCES  :  2 
 # ORCA2_OFF_PISCES  :  3 
 # AMM12             :  4 
 # SAS               :  5
 # ORCA2_SI3_OBS     :  6
 # AGRIF             :  7 & 8  test AGRIF in a double zoom configuration (AGRIF_NORDIC)
 #                               and check that key_agrif without zoom = no key_agrif
 # SPITZ12           :  9      regional configuration including sea-ice and tides (Spitzbergen)
@@ -271,11 +271,11 @@
 
 # -----------------
-# ORCA2_SI3_PISCES
+# ORCA2_ICE_PISCES
 # -----------------
 if [ ${config} -eq 2 ] ;  then
 ## Restartability tests for ORCA2_SI3_PISCES
     export TEST_NAME="LONG"
     cd ${MAIN_DIR}
-    . ./makenemo -m ${CMP_NAM} -n ORCA2_SI3_PISCES_ST -r ORCA2_SI3_PISCES -j 8 del_key ${DEL_KEYS}
+    . ./makenemo -m ${CMP_NAM} -n ORCA2_ICE_PISCES_ST -r ORCA2_ICE_PISCES -j 8 del_key ${DEL_KEYS}
     cd ${SETTE_DIR}
     . ./param.cfg
@@ -314,5 +314,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_ORCA2_SI3_PISCES.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
+    . ./prepare_job.sh input_ORCA2_ICE_PISCES.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
     
     cd ${SETTE_DIR}
@@ -361,9 +361,9 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_ORCA2_SI3_PISCES.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
-    cd ${SETTE_DIR}
-    . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
-
-## Reproducibility tests for ORCA2_SI3_PISCES
+    . ./prepare_job.sh input_ORCA2_ICE_PISCES.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
+    cd ${SETTE_DIR}
+    . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
+
+## Reproducibility tests for ORCA2_ICE_PISCES
     export TEST_NAME="REPRO_4_8"
     cd ${MAIN_DIR}
@@ -402,5 +402,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_ORCA2_SI3_PISCES.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
+    . ./prepare_job.sh input_ORCA2_ICE_PISCES.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
@@ -439,5 +439,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_ORCA2_SI3_PISCES.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
+    . ./prepare_job.sh input_ORCA2_ICE_PISCES.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
@@ -728,5 +728,5 @@
     export TEST_NAME="LONG"
     cd ${MAIN_DIR}
-    . ./makenemo -m ${CMP_NAM} -n ORCA2_SAS_SI3_ST -r ORCA2_SAS_SI3 -j 8 del_key ${DEL_KEYS}
+    . ./makenemo -m ${CMP_NAM} -n ORCA2_SAS_ICE_ST -r ORCA2_SAS_ICE -j 8 del_key ${DEL_KEYS}
     cd ${SETTE_DIR}
     . ./param.cfg
@@ -838,5 +838,5 @@
 
 # --------------
-# ORCA2_SI3_OBS
+# ORCA2_ICE_OBS
 # --------------
 ## Test assimilation interface code, OBS and ASM for reproducibility
@@ -846,5 +846,5 @@
     export TEST_NAME="REPRO_4_8"
     cd ${MAIN_DIR}
-    . ./makenemo -m ${CMP_NAM} -n ORCA2_SI3_OBS_ST -r ORCA2_SI3_PISCES -d "OCE ICE"  -j 8 add_key "key_asminc" del_key "key_top"
+    . ./makenemo -m ${CMP_NAM} -n ORCA2_ICE_OBS_ST -r ORCA2_ICE_PISCES -d "OCE ICE"  -j 8 add_key "key_asminc" del_key "key_top"
     cd ${SETTE_DIR}
     . ./param.cfg
@@ -874,5 +874,5 @@
     set_namelist namelist_cfg ln_sshinc .true.
     set_namelist namelist_cfg ln_asmiau .true.
     #remove all useless options for pisces (due to ORCA2_SI3_PISCES reference configuration)
     set_namelist namelist_top_cfg ln_trcdta .false. 
     # put ln_ironsed, ln_river, ln_ndepo, ln_dust to false
@@ -893,5 +893,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_ORCA2_SI3_OBS.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
+    . ./prepare_job.sh input_ORCA2_ICE_OBS.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
@@ -923,5 +923,5 @@
     set_namelist namelist_cfg ln_sshinc .true.
     set_namelist namelist_cfg ln_asmiau .true.
     #remove all useless options for pisces (due to ORCA2_SI3_PISCES reference configuration)
     set_namelist namelist_top_cfg ln_trcdta .false.
     # put ln_ironsed, ln_river, ln_ndepo, ln_dust to false
@@ -942,5 +942,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_ORCA2_SI3_OBS.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
+    . ./prepare_job.sh input_ORCA2_ICE_OBS.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
@@ -948,5 +948,5 @@
 
 # ------------
-# AGRIF NORDIC
+# AGRIF ICE
 # -----------
 if [ ${config} -eq 7 ] ;  then
@@ -954,5 +954,5 @@
     export TEST_NAME="LONG"
     cd ${MAIN_DIR}
-    . ./makenemo -m ${CMP_NAM} -n AGRIF_NORDIC_ST -r AGRIF_NORDIC -j 8 del_key "key_top"
+    . ./makenemo -m ${CMP_NAM} -n AGRIF_ICE_ST -r AGRIF_ICE -j 8 del_key "key_top"
     cd ${SETTE_DIR}
     . ./param.cfg
@@ -1136,9 +1136,9 @@
 
 
 ## test code corruption with AGRIF (phase 2) ==> Compile without key_agrif (to be compared with AGRIF_NORDIC_ST/ORCA2)
 if [ ${config} -eq 8 ] ;  then
     export TEST_NAME="ORCA2"
     cd ${MAIN_DIR}
-    . ./makenemo -m ${CMP_NAM} -n AGRIF_NORDIC_NOAGRIF_ST -r AGRIF_NORDIC -j 8 del_key "key_top key_agrif"
+    . ./makenemo -m ${CMP_NAM} -n AGRIF_ICE_NOAGRIF_ST -r AGRIF_ICE -j 8 del_key "key_top key_agrif"
     cd ${SETTE_DIR}
     . ./param.cfg
@@ -133,10 +133,10 @@
 # AMM12             :  4 
 # SAS               :  5
-# ORCA2_SI3_OBS     :  6
-# AGRIF             :  7 & 8  test AGRIF in a double zoom configuration (AGRIF_NORDIC)
+# ORCA2_ICE_OBS     :  6
+# AGRIF             :  7 & 8  test AGRIF in a double zoom configuration (AGRIF_ICE)
 #                               and check that key_agrif without zoom = no key_agrif
 # SPITZ12           :  9      regional configuration including sea-ice and tides (Spitzbergen)
@@ -271,11 +271,11 @@
 # -----------------
 if [ ${config} -eq 2 ] ;  then
-## Restartability tests for ORCA2_SI3_PISCES
+## Restartability tests for ORCA2_ICE_PISCES
     export TEST_NAME="LONG"
     cd ${MAIN_DIR}
@@ -874,5 +874,5 @@
     set_namelist namelist_cfg ln_sshinc .true.
     set_namelist namelist_cfg ln_asmiau .true.
-    #remove all useless options for pisces (due to ORCA2_SI3_PISCES reference configuration)
+    #remove all useless options for pisces (due to ORCA2_ICE_PISCES reference configuration)
     set_namelist namelist_top_cfg ln_trcdta .false. 
     # put ln_ironsed, ln_river, ln_ndepo, ln_dust to false
@@ -923,5 +923,5 @@
     set_namelist namelist_cfg ln_sshinc .true.
     set_namelist namelist_cfg ln_asmiau .true.
-    #remove all useless options for pisces (due to ORCA2_SI3_PISCES reference configuration)
+    #remove all useless options for pisces (due to ORCA2_ICE_PISCES reference configuration)
     set_namelist namelist_top_cfg ln_trcdta .false.
     # put ln_ironsed, ln_river, ln_ndepo, ln_dust to false
@@ -1136,9 +1136,9 @@
 
 
-## test code corruption with AGRIF (phase 2) ==> Compile without key_agrif (to be compared with AGRIF_NORDIC_ST/ORCA2)
+## test code corruption with AGRIF (phase 2) ==> Compile without key_agrif (to be compared with AGRIF_ICE_ST/ORCA2)
 if [ ${config} -eq 8 ] ;  then
     export TEST_NAME="ORCA2"